==> amity-sdk-7.7.1-alpha01-sources.jar: main/com/amity/socialcloud/sdk/api/chat/channel/create/AmityLiveChannelCreator.kt <==
package com.amity.socialcloud.sdk.api.chat.channel.create

import com.amity.socialcloud.sdk.model.chat.channel.ChannelCreateOption
import com.amity.socialcloud.sdk.model.core.file.AmityImage
import com.amity.socialcloud.sdk.model.core.tag.AmityTags
import com.google.gson.JsonObject

class AmityLiveChannelCreator {

    class Builder(private val displayName: String) {
        private var avatarFileId: String? = null
        private var metadata: JsonObject? = null
        private var tags: AmityTags? = null
        private var userIds: List<String>? = null
        private var postId: String? = null
        private var videoStreamId: String? = null

        fun avatar(avatar: AmityImage): Builder {
            return apply { this.avatarFileId = avatar.getFileId() }
        }

        fun metadata(metadata: JsonObject): Builder {
            return apply { this.metadata = metadata }
        }

        fun tags(tags: AmityTags): Builder {
            return apply { this.tags = tags }
        }

        fun userIds(userIds: List<String>): Builder {
            return apply { this.userIds = userIds }
        }

        fun postId(postId: String): Builder {
            return apply { this.postId = postId }
        }

        fun videoStreamId(videoStreamId: String): Builder {
            return apply { this.videoStreamId = videoStreamId }
        }

        fun build(): AmityChannelCreator {
            val option = ChannelCreateOption(
                    displayName = displayName,
                    avatarFileId = avatarFileId,
                    metadata = metadata,
                    tags = tags,
                    userIds = userIds,
                    postId = postId,
                    videoStreamId = videoStreamId,
            )

            return AmityChannelCreator(channelType = AmityChannelCreator.CreationType.LIVE, option = option)
        }
    }

}

==> amity-sdk-7.15.0-alpha01-sources.jar: main/com/amity/socialcloud/sdk/api/chat/channel/create/AmityLiveChannelCreator.kt <==
package com.amity.socialcloud.sdk.api.chat.channel.create

import com.amity.socialcloud.sdk.model.chat.channel.ChannelCreateOption
import com.amity.socialcloud.sdk.model.core.file.AmityImage
import com.amity.socialcloud.sdk.model.core.tag.AmityTags
import com.google.gson.JsonObject

class AmityLiveChannelCreator {

    class Builder(private val displayName: String) {
        private var avatarFileId: String? = null
        private var metadata: JsonObject? = null
        private var tags: AmityTags? = null
        private var userIds: List<String>? = null
        private var postId: String? = null
        private var videoStreamId: String? = null
        private var roomId: String? = null


        fun avatar(avatar: AmityImage): Builder {
            return apply { this.avatarFileId = avatar.getFileId() }
        }

        fun metadata(metadata: JsonObject): Builder {
            return apply { this.metadata = metadata }
        }

        fun tags(tags: AmityTags): Builder {
            return apply { this.tags = tags }
        }

        fun userIds(userIds: List<String>): Builder {
            return apply { this.userIds = userIds }
        }

        fun postId(postId: String): Builder {
            return apply { this.postId = postId }
        }

        fun videoStreamId(videoStreamId: String): Builder {
            return apply { this.videoStreamId = videoStreamId }
        }

        fun roomId(roomId: String): Builder {
            return apply { this.roomId = roomId }
        }

        fun build(): AmityChannelCreator {
            val option = ChannelCreateOption(
                    displayName = displayName,
                    avatarFileId = avatarFileId,
                    metadata = metadata,
                    tags = tags,
                    userIds = userIds,
                    postId = postId,
                    videoStreamId = videoStreamId,
                    roomId = roomId,
            )

            return AmityChannelCreator(channelType = AmityChannelCreator.CreationType.LIVE, option = option)
        }
    }

}
